about summary refs log tree commit diff homepage
path: root/include
diff options
context:
space:
mode:
authorDaniel Dunbar <daniel@zuster.org>2009-06-14 21:52:09 +0000
committerDaniel Dunbar <daniel@zuster.org>2009-06-14 21:52:09 +0000
commit25b0ab1a3513b5952c0a2e2c59cec72cdf471224 (patch)
treebce6c8416bb4fad827dbc127bc8f57fce24836b1 /include
parent2ad9c2b4a298c04bcbddc80b50f681e712dfbeba (diff)
downloadklee-25b0ab1a3513b5952c0a2e2c59cec72cdf471224.tar.gz
Rename FoldingExprBuilder -> SimplifyingExprBuilder
Also, start printing query # with -print-ast (for testing purposes).


git-svn-id: https://llvm.org/svn/llvm-project/klee/trunk@73350 91177308-0d34-0410-b5e6-96231b3b80d8
Diffstat (limited to 'include')
-rw-r--r--include/klee/ExprBuilder.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/include/klee/ExprBuilder.h b/include/klee/ExprBuilder.h
index e39da38c..6c1f6809 100644
--- a/include/klee/ExprBuilder.h
+++ b/include/klee/ExprBuilder.h
@@ -69,11 +69,12 @@ namespace klee {
   /// Base - The base builder to use when constructing expressions.
   ExprBuilder *createConstantFoldingExprBuilder(ExprBuilder *Base);
 
   /// createFoldingExprBuilder - Create an expression builder which attemps to
   /// fold redundant expressions and normalize expressions for improved caching.
   ///
   /// Base - The base builder to use when constructing expressions.
-  ExprBuilder *createFoldingExprBuilder(ExprBuilder *Base);
+  ExprBuilder *createSimplifyingExprBuilder(ExprBuilder *Base);
 }
 
 #endif
@@ -69,11 +69,12 @@ namespace klee {
   ExprBuilder *createConstantFoldingExprBuilder(ExprBuilder *Base);
 
-  /// createFoldingExprBuilder - Create an expression builder which attemps to
-  /// fold redundant expressions and normalize expressions for improved caching.
+  /// createSimplifyingExprBuilder - Create an expression builder which attemps
+  /// to fold redundant expressions and normalize expressions for improved
+  /// caching.
   ///
   /// Base - The base builder to use when constructing expressions.